.. role:: hidden
    :class: hidden-section

ax.telemetry
============

.. automodule:: ax.telemetry
.. currentmodule:: ax.telemetry

Experiment
~~~~~~~~~~

.. automodule:: ax.telemetry.experiment
    :members:
    :undoc-members:
    :show-inheritance:

Generation Strategy
~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.telemetry.generation_strategy
    :members:
    :undoc-members:
    :show-inheritance:

Scheduler
~~~~~~~~~

.. automodule:: ax.telemetry.scheduler
    :members:
    :undoc-members:
    :show-inheritance:
